# geodatatool


[![image](https://img.shields.io/pypi/v/geodatatool.svg)](https://pypi.python.org/pypi/geodatatool)
[![image](https://img.shields.io/conda/vn/conda-forge/geodatatool.svg)](https://anaconda.org/conda-forge/geodatatool)
[![image](https://pepy.tech/badge/geodatatool)](https://pepy.tech/project/geodatatool)
[![image](https://github.com/clancygeodata/geodatatool/workflows/docs/badge.svg)](https://clancygeodata.github.io/geodatatool)
[![image](https://github.com/clancygeodata/geodatatool/workflows/build/badge.svg)](https://github.com/clancygeodata/geodatatool/actions?query=workflow%3Abuild)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

**Python package for geographic data tools**


-   Free software: MIT license
-   Documentation: https://clancygeodata.github.io/geodatatool
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
